@@ -193,5 +193,15 @@ class TestUniqueReturnChecker(BaseCheckerTestCase):
                 Foo()
         """)
 
+        with self.assertNoMessages():
+            self.walk(test_func)
+    
+    def test_assign_const(self):
+        test_func = astroid.extract_node("""
+        def test(): #@
+            for n in range(1):
+                x = None
+        """)
+
         with self.assertNoMessages():
             self.walk(test_func)
\ No newline at end of file
